import json
from pathlib import Path

import fiona


# Path to the folder where this script is
ROOT = Path(__file__).parent

# Define the path to the shapefile
out_filename = ROOT / 'shapefile_example2/shapefile_example2.shp'

shapes_json = {
    # name: path2jsonfile
    'labrador-interior': ROOT / 'labrador-interior.json',
}

# NO NEED TO MODIFY BELOW THIS LINE

# Get shapes from files
shapes = []
for region, filepath in shapes_json.items():
    # Opening JSON file
    with open(filepath, 'r') as file:
        data = json.load(file)
    shapes.append({
        'geometry': data,
        'properties': {'name': region}
    })

# Create folder
Path(out_filename).parent.mkdir(parents=True, exist_ok=True)

# Open new file
schema = {
    'geometry':'Polygon',
    'properties':[('name','str')]
}
polyShp = fiona.open(
    out_filename, mode='w',
    driver='ESRI Shapefile',
    schema=schema, crs='EPSG:4326'
)

# Include polygon information
[polyShp.write(shape) for shape in shapes]

# Close file
polyShp.close()
